<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>CategoryDialog</name>
    <message>
        <location filename="../../category_dialog.ui" line="14"/>
        <source>Choose Category</source>
        <translation>Kategorie Auswählen</translation>
    </message>
    <message>
        <location filename="../../category_dialog.ui" line="26"/>
        <source>&amp;Category</source>
        <translation>&amp;Kategorie</translation>
    </message>
</context>
<context>
    <name>ConverterWindow</name>
    <message>
        <source>Unit Converter</source>
        <translation type="vanished">Einheitenkonvertierer</translation>
    </message>
    <message>
        <source>A&amp;mount</source>
        <translation type="vanished">&amp;Menge</translation>
    </message>
    <message>
        <source>&amp;Converted</source>
        <translation type="vanished">&amp;Konvertiert</translation>
    </message>
    <message>
        <location filename="../../converter_window.ui" line="14"/>
        <source>Convert Units</source>
        <translation>Einheiten Konvertieren</translation>
    </message>
    <message>
        <location filename="../../converter_window.ui" line="22"/>
        <source>Amo&amp;unt</source>
        <translation>Men&amp;ge</translation>
    </message>
    <message>
        <location filename="../../converter_window.ui" line="86"/>
        <source>Con&amp;verted</source>
        <translation>Kon&amp;vertiert</translation>
    </message>
    <message>
        <location filename="../../converter_window.ui" line="102"/>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <location filename="../../converter_window.ui" line="79"/>
        <source>kg/l</source>
        <translation>kg/l</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="104"/>
        <source>rolled oats</source>
        <translation>Haferflocken</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="105"/>
        <source>bread crumbs</source>
        <translation>Semmelbrösel</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="106"/>
        <source>desiccated coconut</source>
        <translation>Kokosraspeln</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="107"/>
        <source>cornflour</source>
        <translation>Stärkemehl</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="108"/>
        <source>cocoa</source>
        <translation>Kakao</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="109"/>
        <source>ground almonds</source>
        <translation>gemahlene Mandeln</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="110"/>
        <source>shredded suet</source>
        <translation>zerkleinerter Talg</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="111"/>
        <source>sugar</source>
        <translation>Zucker</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="112"/>
        <source>rice</source>
        <translation>Reis</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="113"/>
        <source>haricots</source>
        <translation>Bohnen</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="114"/>
        <source>lentils</source>
        <translation>Linsen</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="115"/>
        <source>barley</source>
        <translation>Gerste</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="116"/>
        <source>peas</source>
        <translation>Erbsen</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="117"/>
        <source>sultana</source>
        <translation>Sultaninen</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="118"/>
        <source>tapioca</source>
        <translation>Tapioka</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="119"/>
        <source>ground rice</source>
        <translation>gemahlener Reis</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="120"/>
        <source>currants</source>
        <translation>Korinthen</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="121"/>
        <source>semolina</source>
        <translation>Grieß</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="122"/>
        <source>raisins</source>
        <translation>Rosinen</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="123"/>
        <source>custard powder</source>
        <translation>Puddingpulver</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="124"/>
        <source>flour</source>
        <translation>Mehl</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="125"/>
        <source>milk</source>
        <translation>Milch</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="126"/>
        <source>icing sugar</source>
        <translation>Puderzucker</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="127"/>
        <source>Custom</source>
        <translation>benutzerdefiniert</translation>
    </message>
</context>
<context>
    <name>EditDialog</name>
    <message>
        <location filename="../../edit_dialog.ui" line="14"/>
        <source>Edit Recipe</source>
        <translation>Rezept Editieren</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="28"/>
        <source>&amp;General</source>
        <translation>&amp;Allgemein</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="36"/>
        <location filename="../../edit_dialog.ui" line="570"/>
        <source>&amp;Title:</source>
        <translation>&amp;Titel:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="56"/>
        <source>&amp;Categories:</source>
        <translation>&amp;Kategorien:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="73"/>
        <source>&amp;Yield:</source>
        <translation>&amp;Portionen:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="123"/>
        <source>&amp;Ingredients</source>
        <translation>&amp;Zutaten</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="220"/>
        <source>I&amp;ngredient</source>
        <translation>Z&amp;utat</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="146"/>
        <source>Add &amp;Group</source>
        <translation>&amp;Gruppe Hinzufügen</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="153"/>
        <source>Add &amp;Ingredient</source>
        <translation>&amp;Zutat Hinzufügen</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="160"/>
        <location filename="../../edit_dialog.ui" line="654"/>
        <source>&amp;Remove</source>
        <translation>&amp;Entfernen</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="167"/>
        <location filename="../../edit_dialog.ui" line="661"/>
        <source>&amp;Up</source>
        <translation>A&amp;ufwärts</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="178"/>
        <location filename="../../edit_dialog.ui" line="672"/>
        <source>&amp;Down</source>
        <translation>&amp;Abwärts</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="226"/>
        <source>A&amp;mount:</source>
        <translation>&amp;Menge:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="244"/>
        <source>float</source>
        <translation>Fließkomma</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="239"/>
        <source>fraction</source>
        <translation>Bruch</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="49"/>
        <location filename="../../edit_dialog.ui" line="717"/>
        <source>title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="66"/>
        <source>category1, category2, ...</source>
        <translation>Kategorie1, Kategorie2, ...</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="98"/>
        <source>servings</source>
        <translation>Portionen</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="189"/>
        <source>U&amp;nit Converter</source>
        <translation>Ei&amp;nheitenkonvertierer</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="284"/>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="301"/>
        <source>/</source>
        <translation>/</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="359"/>
        <source>Uni&amp;t:</source>
        <translation>Einhei&amp;t:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="370"/>
        <source>per serving</source>
        <translation>pro Portion</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="375"/>
        <source>small</source>
        <translation>kleine</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="380"/>
        <source>medium</source>
        <translation>mittlere</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="385"/>
        <source>large</source>
        <translation>große</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="390"/>
        <source>can</source>
        <translation>Dose</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="395"/>
        <source>package</source>
        <translation>Päckchen</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="400"/>
        <source>pinch</source>
        <translation>Prise</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="405"/>
        <source>drop</source>
        <translation>Tropfen</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="410"/>
        <source>dash</source>
        <translation>Schuss</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="415"/>
        <source>carton</source>
        <translation>Karton</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="420"/>
        <source>bunch</source>
        <translation>Bündel</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="425"/>
        <source>slice</source>
        <translation>Scheibe</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="430"/>
        <source>each</source>
        <translation>pro Stück</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="435"/>
        <source>teaspoon</source>
        <translation>Teelöffel</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="440"/>
        <source>tablespoon</source>
        <translation>Eßlöffel</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="445"/>
        <source>fluid ounce</source>
        <translation>Flüssigunze</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="450"/>
        <source>cup</source>
        <translation>Tasse</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="455"/>
        <source>pint</source>
        <translation>Pint</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="460"/>
        <source>quart</source>
        <translation>Quart</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="465"/>
        <source>gallon</source>
        <translation>Gallone</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="470"/>
        <source>ounce</source>
        <translation>Unze</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="475"/>
        <source>pound</source>
        <translation>Pfund</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="480"/>
        <source>milliliter</source>
        <translation>Milliliter</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="485"/>
        <source>cubic cm</source>
        <translation>Kubikzentimeter</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="490"/>
        <source>centiliter</source>
        <translation>Zentiliter</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="495"/>
        <source>deciliter</source>
        <translation>Deziliter</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="500"/>
        <source>liter</source>
        <translation>Liter</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="505"/>
        <source>milligram</source>
        <translation>Milligramm</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="510"/>
        <source>centigram</source>
        <translation>Zentigramm</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="515"/>
        <source>decigram</source>
        <translation>Dezigramm</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="520"/>
        <source>gram</source>
        <translation>Gramm</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="525"/>
        <source>kilogram</source>
        <translation>Kilogramm</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="538"/>
        <source>Na&amp;me:</source>
        <translation>Na&amp;me:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="562"/>
        <source>Ingredient &amp;Section</source>
        <translation>Zutaten &amp;Absatz</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="609"/>
        <source>Select section or ingredient</source>
        <translation>Wähle Absatz oder Zutat aus</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="693"/>
        <source>Instruction</source>
        <translation>Zubereitung</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="701"/>
        <source>&amp;Title</source>
        <translation>&amp;Titel</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="755"/>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="765"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbruch</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Titel:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="624"/>
        <source>In&amp;structions</source>
        <translation>Zu&amp;bereitung</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="647"/>
        <source>&amp;Add Group</source>
        <translation>&amp;Gruppe Hinzufügen</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="548"/>
        <location filename="../../edit_dialog.cc" line="220"/>
        <source>ingredient</source>
        <translation>Zutat</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.cc" line="242"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
</context>
<context>
    <name>ExportDialog</name>
    <message>
        <location filename="../../export_dialog.ui" line="14"/>
        <source>Export MealMaster Recipes</source>
        <translation>MealMaster Rezepte Exportieren</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="26"/>
        <source>En&amp;coding</source>
        <translation>&amp;Zeichensatz</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="46"/>
        <source>ISO-8859-1</source>
        <translation>ISO-8859-1</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="51"/>
        <source>ISO-8859-15</source>
        <translation>ISO-8859-15</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="56"/>
        <source>CP850</source>
        <translation>CP850</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="61"/>
        <source>UTF-8</source>
        <translation>UTF-8</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="66"/>
        <source>US-ASCII</source>
        <translation>US-ASCII</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="74"/>
        <source>Error Fi&amp;le</source>
        <translation>Feh&amp;lerdatei</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="92"/>
        <source>/tmp/errors.mmf</source>
        <translation>/tmp/fehler.mmf</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="102"/>
        <source>&amp;Select error file</source>
        <translation>Fehlerdatei aus&amp;wählen</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="141"/>
        <source>Proceed with selection of output file</source>
        <translation>Fortfahren mit Auswahl der Ausgabedatei</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="148"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbruch</translation>
    </message>
    <message>
        <location filename="../../export_dialog.cc" line="42"/>
        <source>Select Error File</source>
        <translation>Fehlerdatei auswählen</translation>
    </message>
    <message>
        <location filename="../../export_dialog.cc" line="42"/>
        <source>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;All files (*)</source>
        <translation>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;Alle Dateien (*)</translation>
    </message>
</context>
<context>
    <name>ImportDialog</name>
    <message>
        <location filename="../../import_dialog.ui" line="14"/>
        <source>Import MealMaster Recipes</source>
        <translation>Importiere MealMaster Rezepte</translation>
    </message>
    <message>
        <source>En&amp;coding</source>
        <translation type="vanished">&amp;Zeichensatz</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="26"/>
        <source>Encodin&amp;g</source>
        <translation>&amp;Zeichensatz</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="46"/>
        <source>ISO-8859-1</source>
        <translation>ISO-8859-1</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="51"/>
        <source>ISO-8859-15</source>
        <translation>ISO-8859-15</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="56"/>
        <source>CP850</source>
        <translation>CP850</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="61"/>
        <source>UTF-8</source>
        <translation>UTF-8</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="66"/>
        <source>US-ASCII</source>
        <translation>US-ASCII</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="74"/>
        <source>Error Fi&amp;le</source>
        <translation>Feh&amp;lerdatei</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="92"/>
        <source>/tmp/errors.mmf</source>
        <translation>/tmp/fehler.mmf</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="102"/>
        <source>&amp;Select error file</source>
        <translation>Fehlerdatei aus&amp;wählen</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="141"/>
        <source>Pr&amp;oceed with selection of recipes</source>
        <translation>Mit Auswahl der Rezepte f&amp;ortfahren</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="148"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbruch</translation>
    </message>
    <message>
        <source>errors.mmf</source>
        <translation type="vanished">fehler.mmf</translation>
    </message>
    <message>
        <location filename="../../import_dialog.cc" line="42"/>
        <source>Select Error File</source>
        <translation>Fehlerdatei auswählen</translation>
    </message>
    <message>
        <location filename="../../import_dialog.cc" line="42"/>
        <source>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;All files (*)</source>
        <translation>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;Alle Dateien (*)</translation>
    </message>
</context>
<context>
    <name>IngredientModel</name>
    <message>
        <location filename="../../ingredient_model.cc" line="43"/>
        <source>amount</source>
        <translation>Menge</translation>
    </message>
    <message>
        <location filename="../../ingredient_model.cc" line="45"/>
        <source>unit</source>
        <translation>Einheit</translation>
    </message>
    <message>
        <location filename="../../ingredient_model.cc" line="47"/>
        <source>ingredient</source>
        <translation>Zutat</translation>
    </message>
    <message>
        <location filename="../../ingredient_model.cc" line="76"/>
        <location filename="../../ingredient_model.cc" line="215"/>
        <source>&lt;Main&gt;</source>
        <translation>&lt;Kopf&gt;</translation>
    </message>
</context>
<context>
    <name>InstructionsModel</name>
    <message>
        <location filename="../../instructions_model.cc" line="52"/>
        <location filename="../../instructions_model.cc" line="62"/>
        <source>&lt;Main&gt;</source>
        <translation>&lt;Kopf&gt;</translation>
    </message>
    <message>
        <location filename="../../instructions_model.cc" line="78"/>
        <source>section</source>
        <translation>Absatz</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../main_window.ui" line="14"/>
        <source>AnyMeal</source>
        <translation>AnyMeal</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="27"/>
        <source>&amp;Show all recipes</source>
        <translation>Alle Rezepte an&amp;zeigen</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="34"/>
        <source>&amp;Title</source>
        <translation>&amp;Titel</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="44"/>
        <source>Search for title text.</source>
        <translation>Suche Titeltext.</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="74"/>
        <source>&amp;Category</source>
        <translation>&amp;Kategorie</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="84"/>
        <source>Search for categories.</source>
        <translation>Suche Kategorien.</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="94"/>
        <source>Search for recipes with ingredient.</source>
        <translation>Suche Rezepte mit einer Zutat.</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="54"/>
        <location filename="../../main_window.ui" line="97"/>
        <source>w</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="107"/>
        <source>Search for recipes without ingredient.</source>
        <translation>Suche Rezepte ohne eine Zutat.</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="64"/>
        <location filename="../../main_window.ui" line="110"/>
        <source>w/o</source>
        <translation>o</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="120"/>
        <source>&amp;Ingredient</source>
        <translation>Z&amp;utat</translation>
    </message>
    <message>
        <source>&amp;Filter</source>
        <translation type="vanished">&amp;Filtern</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="201"/>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="214"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>toolBar</source>
        <translation type="vanished">toolBar</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="264"/>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="270"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="279"/>
        <source>&amp;Import recipes</source>
        <translation>Rezepte &amp;importieren</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation type="vanished">&amp;Importieren</translation>
    </message>
    <message>
        <source>tool bar</source>
        <translation type="vanished">Werkzeugleiste</translation>
    </message>
    <message>
        <source>Categor&amp;y</source>
        <translation type="vanished">Kategor&amp;ie</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="130"/>
        <source>Specify the ingredient.</source>
        <translation>Zutat spezifizieren.</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="137"/>
        <source>&amp;Search</source>
        <translation>&amp;Suchen</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="221"/>
        <source>Edit</source>
        <translation>Editieren</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="236"/>
        <source>Tool Bar</source>
        <translation>Werkzeugleiste</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="267"/>
        <source>Exit application</source>
        <translation>Programm beenden</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="282"/>
        <source>Read MealMaster recipes from files</source>
        <translation>MealMaster Rezepte aus Dateien lesen</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="285"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="294"/>
        <source>Print p&amp;review</source>
        <translation>&amp;Druckvorschau</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="297"/>
        <source>Print preview of current recipe</source>
        <translation>Druckvorschau für aktuelles Rezept</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="300"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="309"/>
        <source>&amp;Print recipe</source>
        <translation>Rezept d&amp;rucken</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="312"/>
        <source>Print current recipe</source>
        <translation>Drucke aktuelles Rezept</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="315"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="324"/>
        <source>A&amp;bout AnyMeal</source>
        <translation>Ü&amp;ber AnyMeal</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="327"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="336"/>
        <source>&amp;Delete recipes</source>
        <translation>Rezepte &amp;löschen</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="339"/>
        <source>Delete selected recipes</source>
        <translation>Ausgewählte Rezepte löschen</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="342"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="351"/>
        <source>Exp&amp;ort recipes</source>
        <translation>Rezepte exp&amp;ortieren</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="354"/>
        <source>Write MealMaster recipes to file</source>
        <translation>MealMaster Rezepte in Datei speichern</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="357"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="366"/>
        <source>&amp;Edit Recipe</source>
        <translation>Rezept &amp;Editieren</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="369"/>
        <source>Edit current recipe</source>
        <translation>Aktuelles Rezept editieren</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="381"/>
        <source>Collect &amp;Garbage</source>
        <translation>&amp;Müll bereinigen</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="384"/>
        <source>Delete unused categories and ingredients</source>
        <translation>Unbenutzte Kategorien und Zutaten löschen</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="387"/>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="396"/>
        <source>Add &amp;to Category</source>
        <translation>&amp;Zu Kategorie Hinzufügen</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="402"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="411"/>
        <source>&amp;Remove from Category</source>
        <translation>Aus Kategorie &amp;Entfernen</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="414"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="423"/>
        <source>Open Co&amp;nverter Window</source>
        <translation>Öffne Ko&amp;nverterfenster</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="426"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="453"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="435"/>
        <source>Remove duplicates</source>
        <translation>Duplikate entfernen</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="438"/>
        <source>Remove duplicates in selected recipes</source>
        <translation>Duplikate in ausgewählten Rezepten entfernen</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="447"/>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="450"/>
        <source>New recipe</source>
        <translation>Neues Rezept</translation>
    </message>
    <message>
        <source>&amp;Add to Category</source>
        <translation type="vanished">Zur K&amp;ategory Hinzufügen</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="399"/>
        <source>Add selected recipes to a category</source>
        <translation>Ausgewählte Rezepte zur Kategorie hinzufügen</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation type="vanished">Ctrl+A</translation>
    </message>
    <message>
        <source>&amp;Export recipes</source>
        <translation type="vanished">Rezepte &amp;Exportieren</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="372"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="92"/>
        <source>Error Opening Database</source>
        <translation>Fehler beim Öffnen der Datenbank</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="108"/>
        <source>Import MealMaster Files</source>
        <translation>Importiere MealMaster Dateien</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="108"/>
        <location filename="../../main_window.cc" line="438"/>
        <source>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;All files (*)</source>
        <translation>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;Alle Dateien (*)</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="114"/>
        <source>Importing files ...</source>
        <translation>Importiere Dateien ...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="114"/>
        <location filename="../../main_window.cc" line="445"/>
        <location filename="../../main_window.cc" line="546"/>
        <source>Cancel</source>
        <translation>Abbruch</translation>
    </message>
    <message>
        <source>Processing file %1 ...</source>
        <translation type="vanished">Verarbeite Datei %1 ...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="123"/>
        <source>%1 imported and %2 failed ...</source>
        <translation>%1 importiert und %2 fehlgeschlagen ...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="137"/>
        <source>Rejected recipe: </source>
        <translation>Rezept abgelehnt: </translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="142"/>
        <location filename="../../main_window.cc" line="469"/>
        <location filename="../../main_window.cc" line="477"/>
        <source>Error writing to file </source>
        <translation>Fehler beim Schreiben der Datei </translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="163"/>
        <source>Recipes Imported</source>
        <translation>Importierte Rezepte</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="163"/>
        <source>%1 imported and %2 failed.</source>
        <translation>%1 importiert und %2 fehlgeschlagen.</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="167"/>
        <source>Error While Importing</source>
        <translation>Fehler beim Importieren</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="178"/>
        <source>Edit current recipe, a copy of the recipe, a new recipe, or cancel?</source>
        <translation>Editiere aktuelles Rezept, eine Kopie des Rezepts, ein neues Rezept, oder abbrechen?</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="179"/>
        <source>&amp;Edit Current</source>
        <translation>&amp;Editiere Aktuelles</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="180"/>
        <source>Edit C&amp;opy</source>
        <translation>&amp;Kopie Editieren</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="181"/>
        <source>Edit &amp;New</source>
        <translation>Editiere &amp;Neues</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="250"/>
        <source>Error While Updating Recipe</source>
        <translation>Fehler beim Aktualisieren des Rezepts</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="275"/>
        <source>Error Adding Recipes to Category</source>
        <translation>Fehler beim Hinzufügen zur Kategorie</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="301"/>
        <source>Error Removing Recipes from Category</source>
        <translation>Fehler beim Entfernen der Rezepte aus einer Kategorie</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="320"/>
        <source>Error Collecting Garbage</source>
        <translation>Fehler beim Müll Bereinigen</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="464"/>
        <source>Failed recipe: </source>
        <translation>Fehlgeschlagenes Rezept:</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="546"/>
        <source>Detecting duplicates ...</source>
        <translation>Suche Duplikate ...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="549"/>
        <source>Found %1 duplicates ...</source>
        <translation>%1 Duplikate gefunden ...</translation>
    </message>
    <message>
        <source>About AnyMeal</source>
        <translation type="vanished">Über AnyMeal</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="98"/>
        <source>Showing %1 recipes ...</source>
        <translation>Zeige %1 Rezepte ...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="182"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbruch</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="329"/>
        <source>About AnyMeal %1</source>
        <translation>Über AnyMeal %1</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="374"/>
        <source>Error Filtering Recipes</source>
        <translation>Fehler beim Filtern der Rezepte</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="388"/>
        <source>Error Resetting Selection</source>
        <translation>Fehler beim Zurücksetzen der Auswahl</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="408"/>
        <source>Error fetching recipe</source>
        <translation>Fehler beim Abrufen des Rezepts</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="438"/>
        <source>Export MealMaster File</source>
        <translation>Exportiere MealMaster Datei</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="445"/>
        <source>Exporting recipes ...</source>
        <translation>Exportiere Rezepte ...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="480"/>
        <source>%1 exported and %2 failed ...</source>
        <translation>%1 exportiert und %2 fehlgeschlagen ...</translation>
    </message>
    <message>
        <source>%1 exported and %2 failed</source>
        <translation type="vanished">%1 exportiert und %2 fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="483"/>
        <source>Recipes Exported</source>
        <translation>Exportierte Rezepte</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="483"/>
        <source>%1 exported and %2 failed.</source>
        <translation>%1 exportiert und %2 fehlgeschlagen.</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="487"/>
        <source>Error While Exporting</source>
        <translation>Fehler beim Exportieren</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="495"/>
        <source>Delete Recipes</source>
        <translation>Rezept löschen</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="495"/>
        <source>Do you want to delete the selected recipes?</source>
        <translation>Wollen Sie die ausgewählten Rezepte löschen?</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="514"/>
        <source>Error Deleting Recipes</source>
        <translation>Fehler beim Löschen der Rezepte</translation>
    </message>
</context>
<context>
    <name>recipe</name>
    <message>
        <location filename="../../html.cc" line="183"/>
        <source>Categories</source>
        <translation>Kategorien</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="192"/>
        <source>Yield</source>
        <translation>Portionen</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="196"/>
        <source>Ingredients</source>
        <translation>Zutaten</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="199"/>
        <source>amount</source>
        <translation>Menge</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="200"/>
        <source>unit</source>
        <translation>Einheit</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="201"/>
        <source>ingredient</source>
        <translation>Zutat</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="221"/>
        <source>Instructions</source>
        <translation>Zubereitung</translation>
    </message>
</context>
<context>
    <name>units</name>
    <message>
        <location filename="../../html.cc" line="60"/>
        <source>per serving</source>
        <translation>pro Portion</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="61"/>
        <source>small</source>
        <translation>kleine</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="62"/>
        <source>medium</source>
        <translation>mittlere</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="63"/>
        <source>large</source>
        <translation>große</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="64"/>
        <source>can</source>
        <translation>Dose</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="65"/>
        <source>package</source>
        <translation>Päckchen</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="66"/>
        <source>pinch</source>
        <translation>Prise</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="67"/>
        <source>drop</source>
        <translation>Tropfen</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="68"/>
        <source>dash</source>
        <translation>Schuss</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="69"/>
        <source>carton</source>
        <translation>Karton</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="70"/>
        <source>bunch</source>
        <translation>Bündel</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="71"/>
        <source>slice</source>
        <translation>Scheibe</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="72"/>
        <source>each</source>
        <translation>pro Stück</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="73"/>
        <location filename="../../html.cc" line="74"/>
        <source>teaspoon</source>
        <translation>Teelöffel</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="75"/>
        <location filename="../../html.cc" line="76"/>
        <source>tablespoon</source>
        <translation>Eßlöffel</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="77"/>
        <source>fluid ounce</source>
        <translation>Flüssigunze</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="78"/>
        <source>cup</source>
        <translation>Tasse</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="79"/>
        <source>pint</source>
        <translation>Pint</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="80"/>
        <source>quart</source>
        <translation>Quart</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="81"/>
        <source>gallon</source>
        <translation>Gallone</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="82"/>
        <source>ounce</source>
        <translation>Unze</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="83"/>
        <source>pound</source>
        <translation>Pfund</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="84"/>
        <source>milliliter</source>
        <translation>Milliliter</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="85"/>
        <source>cubic cm</source>
        <translation>Kubikzentimeter</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="86"/>
        <source>centiliter</source>
        <translation>Zentiliter</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="87"/>
        <source>deciliter</source>
        <translation>Deziliter</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="88"/>
        <source>liter</source>
        <translation>Liter</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="89"/>
        <source>milligram</source>
        <translation>Milligramm</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="90"/>
        <source>centigram</source>
        <translation>Zentigramm</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="91"/>
        <source>decigram</source>
        <translation>Dezigramm</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="92"/>
        <source>gram</source>
        <translation>Gramm</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="93"/>
        <source>kilogram</source>
        <translation>Kilogramm</translation>
    </message>
</context>
</TS>
